# kintro

[![PyPI](https://img.shields.io/pypi/v/kintro?style=plastic)](https://pypi.org/project/kintro/)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/kintro?style=plastic)
[![GitHub Workflow Status (main)](https://img.shields.io/github/workflow/status/neckbeard-io/kintro/Python%20package/main?style=plastic)](https://github.com/neckbeard-io/kintro/actions/workflows/check.yml)
[![GitHub last commit (branch)](https://img.shields.io/github/last-commit/neckbeard-io/kintro/main?style=plastic)](https://github.com/neckbeard-io/kintro/commit/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/neckbeard-io/kintro/main.svg)](https://results.pre-commit.ci/latest/github/neckbeard-io/kintro/main)
[![GitHub license](https://img.shields.io/github/license/Naereen/StrapDown.js.svg)](https://github.com/neckbeard-io/kintro/blob/master/LICENSE)

### CONTRIBUTING
[Contributing Guide](CONTRIBUTING.md)

### PACKAGING
[Packaging Guide](PACKAGING.md)
